summaryrefslogtreecommitdiffstats
path: root/knewsticker/knewstickerconfig.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:14:03 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:14:03 -0600
commit9c9412b30c54468adc9e506cc76c5d113fbf5056 (patch)
tree68a0c0d5bc770fc58596b8c5624cdf33d8625027 /knewsticker/knewstickerconfig.cpp
parent2e53bd0b77676f879fad7baeecea5879bf496a7d (diff)
downloadtdenetwork-9c9412b30c54468adc9e506cc76c5d113fbf5056.tar.gz
tdenetwork-9c9412b30c54468adc9e506cc76c5d113fbf5056.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'knewsticker/knewstickerconfig.cpp')
-rw-r--r--knewsticker/knewstickerconfig.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/knewsticker/knewstickerconfig.cpp b/knewsticker/knewstickerconfig.cpp
index aec193cb..6bb6407c 100644
--- a/knewsticker/knewstickerconfig.cpp
+++ b/knewsticker/knewstickerconfig.cpp
@@ -103,7 +103,7 @@ KNewsTickerConfig::KNewsTickerConfig(ConfigAccess *cfg, TQWidget *parent, const
m_child->niInterval->setRange(4, 180);
m_child->lvNewsSources->setShowSortIndicator(true);
- m_child->lvNewsSources->setSelectionModeExt(KListView::Extended);
+ m_child->lvNewsSources->setSelectionModeExt(TDEListView::Extended);
m_child->lvNewsSources->setAcceptDrops(true);
m_child->lvNewsSources->viewport()->setAcceptDrops(true);
m_child->lvNewsSources->viewport()->installEventFilter(this);
@@ -112,8 +112,8 @@ KNewsTickerConfig::KNewsTickerConfig(ConfigAccess *cfg, TQWidget *parent, const
connect(m_newsIconMgr, TQT_SIGNAL(gotIcon(const KURL &, const TQPixmap &)), TQT_SLOT(slotGotNewsIcon(const KURL &, const TQPixmap &)));
connect(m_child->bChooseFont, TQT_SIGNAL(clicked()), TQT_SLOT(slotChooseFont()));
- connect(m_child->lvNewsSources, TQT_SIGNAL(contextMenu(KListView *, TQListViewItem *, const TQPoint &)),
- TQT_SLOT(slotNewsSourceContextMenu(KListView *, TQListViewItem *, const TQPoint &)));
+ connect(m_child->lvNewsSources, TQT_SIGNAL(contextMenu(TDEListView *, TQListViewItem *, const TQPoint &)),
+ TQT_SLOT(slotNewsSourceContextMenu(TDEListView *, TQListViewItem *, const TQPoint &)));
connect(m_child->lvNewsSources, TQT_SIGNAL(selectionChanged()),
TQT_SLOT(slotNewsSourceSelectionChanged()));
connect(m_child->lvNewsSources, TQT_SIGNAL(doubleClicked(TQListViewItem *, const TQPoint &, int)),
@@ -221,7 +221,7 @@ void KNewsTickerConfig::save()
bool KNewsTickerConfig::eventFilter(TQObject *o, TQEvent *e)
{
//<HACK>
// "if ( e->type() == TQEvent::DragEnter ) {" shoult normaly be enough. but there must be a bug somewhere in KListView.
if ( e->type() == TQEvent::DragMove ) {
//</HACK>
TQDragEnterEvent *d = (TQDragEnterEvent*)e;
@@ -349,12 +349,12 @@ void KNewsTickerConfig::removeFilter(TQListViewItem *item)
}
}
-void KNewsTickerConfig::slotNewsSourceContextMenu(KListView *, TQListViewItem *item, const TQPoint &)
+void KNewsTickerConfig::slotNewsSourceContextMenu(TDEListView *, TQListViewItem *item, const TQPoint &)
{
if (!dynamic_cast<NewsSourceItem *>(item))
return;
- KPopupMenu *menu = new KPopupMenu();
+ TDEPopupMenu *menu = new TDEPopupMenu();
TQPixmap addIcon = SmallIcon(TQString::fromLatin1("news_subscribe"));
TQPixmap modifyIcon = SmallIcon(TQString::fromLatin1("edit"));
@@ -388,11 +388,11 @@ void KNewsTickerConfig::slotNewsSourceContextMenu(KListView *, TQListViewItem *i
void KNewsTickerConfig::slotChooseFont()
{
- KFontDialog fd(this, "Font Dialog", false, true);
+ TDEFontDialog fd(this, "Font Dialog", false, true);
fd.setFont(m_font);
- if (fd.exec() == KFontDialog::Accepted) {
+ if (fd.exec() == TDEFontDialog::Accepted) {
if (m_font != fd.font()) {
m_font = fd.font();
}
@@ -221,7 +221,7 @@ void KNewsTickerConfig::save()
{
//<HACK>
- // "if ( e->type() == TQEvent::DragEnter ) {" shoult normaly be enough. but there must be a bug somewhere in KListView.
+ // "if ( e->type() == TQEvent::DragEnter ) {" shoult normaly be enough. but there must be a bug somewhere in TDEListView.
if ( e->type() == TQEvent::DragMove ) {
//</HACK>